# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.knowledge_api import KnowledgeApi


class TestKnowledgeApi(unittest.TestCase):
    """KnowledgeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = KnowledgeApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_knowledge_assertion_client_id_entity_id_get(self) -> None:
        """Test case for api_v1_knowledge_assertion_client_id_entity_id_get

        Get Assertions by Entity
        """
        pass

    def test_api_v1_knowledge_assertion_post(self) -> None:
        """Test case for api_v1_knowledge_assertion_post

        Create Knowledge Assertion
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_get(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_get

        Get Enrichment Artifact
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_output_put(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_output_put

        Update Enrichment Artifact Output
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_status_put(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_status_put

        Update Enrichment Artifact Status
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_get(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_get

        Get Many Enrichment Artifacts
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_post(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_post

        Create Enrichment Artifact
        """
        pass

    def test_api_v1_knowledge_entity_get(self) -> None:
        """Test case for api_v1_knowledge_entity_get

        Get Knowledge Entities
        """
        pass

    def test_api_v1_knowledge_entity_post(self) -> None:
        """Test case for api_v1_knowledge_entity_post

        Create Knowledge Entities
        """
        pass

    def test_api_v1_knowledge_entity_upsert_post(self) -> None:
        """Test case for api_v1_knowledge_entity_upsert_post

        Bulk Uspert Entities
        """
        pass

    def test_api_v1_knowledge_extract_product_post(self) -> None:
        """Test case for api_v1_knowledge_extract_product_post

        Bulk upsert Knowledge Products
        """
        pass

    def test_api_v1_knowledge_ingest_raw_post(self) -> None:
        """Test case for api_v1_knowledge_ingest_raw_post

        Ingest raw source payloads
        """
        pass

    def test_api_v1_knowledge_kind_get(self) -> None:
        """Test case for api_v1_knowledge_kind_get

        Get Knowledge Kinds
        """
        pass

    def test_api_v1_knowledge_schema_get(self) -> None:
        """Test case for api_v1_knowledge_schema_get

        Get Knowledge Entity Schemas
        """
        pass

    def test_api_v1_knowledge_schema_post(self) -> None:
        """Test case for api_v1_knowledge_schema_post

        Upsert a Knowledge Entity Schema
        """
        pass

    def test_api_v1_knowledge_type_get(self) -> None:
        """Test case for api_v1_knowledge_type_get

        Get Knowledge Types
        """
        pass

    def test_api_v1_knowledge_type_post(self) -> None:
        """Test case for api_v1_knowledge_type_post

        Get Knowledge Types
        """
        pass


if __name__ == '__main__':
    unittest.main()
