# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse

class TestOrganizationsDetailResponse(unittest.TestCase):
    """OrganizationsDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsDetailResponse:
        """Test OrganizationsDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsDetailResponse`
        """
        model = OrganizationsDetailResponse()
        if include_optional:
            return OrganizationsDetailResponse(
                branding = neurograph.v1.models.organizations/brand.organizations.Brand(
                    background_img_url = '', 
                    color1 = '', 
                    color2 = '', 
                    color3 = '', 
                    color4 = '', 
                    color5 = '', 
                    id = 56, 
                    logo_img_url = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                description = '',
                error = '',
                id = 'org_123',
                image_url = '',
                is_active = True,
                name = '',
                ts_created = 56,
                ts_updated = 56,
                uid = '',
                url = '',
                workbench = neurograph.v1.models.organizations/workbench_config.organizations.WorkbenchConfig(
                    description = '', 
                    org_id = 'org_123', 
                    version = '', 
                    version_name = '', 
                    workbench_is_active = True, 
                    workbench_url = '', 
                    workbench_url_ext = '', )
            )
        else:
            return OrganizationsDetailResponse(
        )
        """

    def testOrganizationsDetailResponse(self):
        """Test OrganizationsDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
