# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse

class TestClientGetDetailResponse(unittest.TestCase):
    """ClientGetDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientGetDetailResponse:
        """Test ClientGetDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientGetDetailResponse`
        """
        model = ClientGetDetailResponse()
        if include_optional:
            return ClientGetDetailResponse(
                data = neurograph.v1.models.client/client.client.Client(
                    id = '', 
                    is_active = True, 
                    name = '', 
                    org_id = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', 
                    urls = [
                        neurograph.v1.models.db/client_url.db.ClientUrl(
                            client_id = 'cli_12345', 
                            customer_environment = '', 
                            id = 56, 
                            is_active = True, 
                            url = 'example.com', )
                        ], ),
                error = ''
            )
        else:
            return ClientGetDetailResponse(
        )
        """

    def testClientGetDetailResponse(self):
        """Test ClientGetDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
