# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery

class TestKnowledgeOrderQuery(unittest.TestCase):
    """KnowledgeOrderQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeOrderQuery:
        """Test KnowledgeOrderQuery
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeOrderQuery`
        """
        model = KnowledgeOrderQuery()
        if include_optional:
            return KnowledgeOrderQuery(
                billing_address_hash = '',
                channel = '',
                client_id = '',
                currency = '',
                customer_entity_id = '',
                email_at_order = '',
                ext_order_id = '',
                ext_order_number = '',
                ext_store_id = '',
                financial_status = '',
                fulfillment_status = '',
                limit = 56,
                offset = 56,
                phone_at_order = '',
                placed_from = '',
                placed_to = '',
                shipping_address_hash = '',
                source_name = '',
                status = '',
                store_entity_id = '',
                total_max = '',
                total_min = ''
            )
        else:
            return KnowledgeOrderQuery(
        )
        """

    def testKnowledgeOrderQuery(self):
        """Test KnowledgeOrderQuery"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
