# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse

class TestOrganizationsGetManyResponse(unittest.TestCase):
    """OrganizationsGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGetManyResponse:
        """Test OrganizationsGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGetManyResponse`
        """
        model = OrganizationsGetManyResponse()
        if include_optional:
            return OrganizationsGetManyResponse(
                data = [
                    neurograph.v1.models.organizations/organization.organizations.Organization(
                        description = '', 
                        id = 'org_123', 
                        image_url = '', 
                        is_active = True, 
                        name = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        uid = '', 
                        url = '', )
                    ],
                error = '',
                limit = 56,
                offset = 56,
                total_rows = 56
            )
        else:
            return OrganizationsGetManyResponse(
        )
        """

    def testOrganizationsGetManyResponse(self):
        """Test OrganizationsGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
