# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest

class TestPersonasInstanceCreateRequest(unittest.TestCase):
    """PersonasInstanceCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasInstanceCreateRequest:
        """Test PersonasInstanceCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasInstanceCreateRequest`
        """
        model = PersonasInstanceCreateRequest()
        if include_optional:
            return PersonasInstanceCreateRequest(
                age = 1.337,
                description = '',
                female = 1.337,
                income = '',
                male = 1.337,
                metadata = '',
                name = '',
                persona_seed_id = '',
                personality_background = '',
                personality_first_name = '',
                personality_img_url = '',
                personality_last_name = '',
                personality_quote = '',
                personality_video_url = '',
                positioning_statement = '',
                summary_detail = '',
                summary_headline = '',
                tag = '',
                value = ''
            )
        else:
            return PersonasInstanceCreateRequest(
        )
        """

    def testPersonasInstanceCreateRequest(self):
        """Test PersonasInstanceCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
