# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact

class TestKnowledgeEnrichmentArtifact(unittest.TestCase):
    """KnowledgeEnrichmentArtifact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifact:
        """Test KnowledgeEnrichmentArtifact
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifact`
        """
        model = KnowledgeEnrichmentArtifact()
        if include_optional:
            return KnowledgeEnrichmentArtifact(
                agent_engine_run_id = '',
                artifact_id = 56,
                attempt_count = 56,
                client_id = '',
                cloud_run_execution_id = '',
                cloud_run_job_name = '',
                completed_at = '',
                confidence = 1.337,
                config_entity_id = '',
                config_snapshot = None,
                created_at = '',
                input_params = None,
                is_current = True,
                job_name = '',
                last_error = '',
                output_json = None,
                output_schema_id = '',
                output_text = '',
                queued_at = '',
                spec_version = 56,
                started_at = '',
                status = '',
                subject_entity_id = '',
                supersedes_artifact_id = 56,
                task_name = '',
                task_queue_name = ''
            )
        else:
            return KnowledgeEnrichmentArtifact(
        )
        """

    def testKnowledgeEnrichmentArtifact(self):
        """Test KnowledgeEnrichmentArtifact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
