# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse

class TestKnowledgeEnrichmentArtifactListResponse(unittest.TestCase):
    """KnowledgeEnrichmentArtifactListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactListResponse:
        """Test KnowledgeEnrichmentArtifactListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactListResponse`
        """
        model = KnowledgeEnrichmentArtifactListResponse()
        if include_optional:
            return KnowledgeEnrichmentArtifactListResponse(
                data = [
                    neurograph.v1.models.knowledge/enrichment_artifact.knowledge.EnrichmentArtifact(
                        agent_engine_run_id = '', 
                        artifact_id = 56, 
                        attempt_count = 56, 
                        client_id = '', 
                        cloud_run_execution_id = '', 
                        cloud_run_job_name = '', 
                        completed_at = '', 
                        confidence = 1.337, 
                        config_entity_id = '', 
                        config_snapshot = neurograph.v1.models.config_snapshot.config_snapshot(), 
                        created_at = '', 
                        input_params = neurograph.v1.models.input_params.input_params(), 
                        is_current = True, 
                        job_name = '', 
                        last_error = '', 
                        output_json = neurograph.v1.models.output_json.output_json(), 
                        output_schema_id = '', 
                        output_text = '', 
                        queued_at = '', 
                        spec_version = 56, 
                        started_at = '', 
                        status = '', 
                        subject_entity_id = '', 
                        supersedes_artifact_id = 56, 
                        task_name = '', 
                        task_queue_name = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/enrichment_query.knowledge.EnrichmentQuery(
                    client_id = '', 
                    is_current = True, 
                    job_name = '', 
                    kind = '', 
                    limit = 56, 
                    offset = 56, 
                    status = '', 
                    subject_entity_id = '', )
            )
        else:
            return KnowledgeEnrichmentArtifactListResponse(
        )
        """

    def testKnowledgeEnrichmentArtifactListResponse(self):
        """Test KnowledgeEnrichmentArtifactListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
