# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.client_api import ClientApi


class TestClientApi(unittest.TestCase):
    """ClientApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClientApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_client_personas_client_id_get(self) -> None:
        """Test case for api_v1_client_personas_client_id_get

        Get Client's Personas
        """
        pass

    def test_api_v1_client_url_client_id_get(self) -> None:
        """Test case for api_v1_client_url_client_id_get

        Get client's URLs
        """
        pass

    def test_api_v1_client_url_post(self) -> None:
        """Test case for api_v1_client_url_post

        Upsert a Client Url
        """
        pass

    def test_api_v1_client_url_probe_client_id_post(self) -> None:
        """Test case for api_v1_client_url_probe_client_id_post

        Trigger client URL probes
        """
        pass

    def test_api_v1_client_url_snapshot_probe_id_get(self) -> None:
        """Test case for api_v1_client_url_snapshot_probe_id_get

        Get a client's URL snapshot by probe id
        """
        pass

    def test_api_v1_clients_client_id_get(self) -> None:
        """Test case for api_v1_clients_client_id_get

        Get Client by ID
        """
        pass

    def test_api_v1_clients_client_id_users_get(self) -> None:
        """Test case for api_v1_clients_client_id_users_get

        Client's assigned users and their permissions
        """
        pass

    def test_api_v1_clients_get(self) -> None:
        """Test case for api_v1_clients_get

        Get Clients
        """
        pass

    def test_api_v1_clients_post(self) -> None:
        """Test case for api_v1_clients_post

        Upsert a Client
        """
        pass


if __name__ == '__main__':
    unittest.main()
