# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_metadata_response import ClientMetadataResponse

class TestClientMetadataResponse(unittest.TestCase):
    """ClientMetadataResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientMetadataResponse:
        """Test ClientMetadataResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientMetadataResponse`
        """
        model = ClientMetadataResponse()
        if include_optional:
            return ClientMetadataResponse(
                client = neurograph.v1.models.client/info.client.Info(
                    id = '', 
                    is_active = True, 
                    name = '', 
                    org_id = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', ),
                error = '',
                metadata = [
                    neurograph.v1.models.client/metadata.client.Metadata(
                        key = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        value = '', )
                    ],
                organization = neurograph.v1.models.client/organization_detail.client.OrganizationDetail(
                    branding = neurograph.v1.models.client/organization_brand.client.OrganizationBrand(
                        background_img_url = '', 
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        id = '', 
                        logo_img_url = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tertiary_color = '', ), 
                    description = '', 
                    id = '', 
                    image_url = '', 
                    is_active = True, 
                    name = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', 
                    url = '', 
                    workbench = neurograph.v1.models.client/workbench_config.client.WorkbenchConfig(
                        description = '', 
                        org_id = '', 
                        version = '', 
                        version_name = '', 
                        workbench_is_active = True, 
                        workbench_url = '', 
                        workbench_url_ext = '', ), )
            )
        else:
            return ClientMetadataResponse(
        )
        """

    def testClientMetadataResponse(self):
        """Test ClientMetadataResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
